Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(290)

Unified Diff: chrome/android/shell/java/src/org/chromium/chrome/shell/ChromeShellToolbar.java

Issue 914083003: Hide Url bar in tab switcher mode. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Review changes Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/android/shell/java/src/org/chromium/chrome/shell/TabManager.java » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/android/shell/java/src/org/chromium/chrome/shell/ChromeShellToolbar.java
diff --git a/chrome/android/shell/java/src/org/chromium/chrome/shell/ChromeShellToolbar.java b/chrome/android/shell/java/src/org/chromium/chrome/shell/ChromeShellToolbar.java
index f10978a2825fb6ada445f5e4a497c56e1675078a..928c8808c3e402abcbbe50945651b31b574a8831 100644
--- a/chrome/android/shell/java/src/org/chromium/chrome/shell/ChromeShellToolbar.java
+++ b/chrome/android/shell/java/src/org/chromium/chrome/shell/ChromeShellToolbar.java
@@ -180,7 +180,7 @@ public class ChromeShellToolbar extends LinearLayout {
public void onFocusChange(View v, boolean hasFocus) {
setKeyboardVisibilityForUrl(hasFocus);
mFocus = hasFocus;
- updateToolBarButtonState();
+ updateToolbarState();
if (!hasFocus && mTab != null) {
mUrlTextView.setText(mTab.getWebContents().getUrl());
mSuggestionPopup.dismissPopup();
@@ -258,12 +258,13 @@ public class ChromeShellToolbar extends LinearLayout {
}
/**
* Shows or hides the add and the stop/reload button.
*/
- public void updateToolBarButtonState() {
+ public void updateToolbarState() {
boolean tabSwitcherState = mTabManager.isTabSwitcherVisible();
mAddButton.setVisibility(tabSwitcherState ? VISIBLE : GONE);
mStopReloadButton.setVisibility(tabSwitcherState || mFocus ? GONE : VISIBLE);
+ mUrlTextView.setVisibility(tabSwitcherState ? INVISIBLE : VISIBLE);
}
/**
« no previous file with comments | « no previous file | chrome/android/shell/java/src/org/chromium/chrome/shell/TabManager.java » ('j') | no next file with comments »
@@ -258,12 +258,13 @@ public class ChromeShellToolbar extends LinearLayout {
}
/**
- * Shows or hides the add and the stop/reload button.
+ * Shows or hides the add button, the stop/reload button and the URL bar.
*/

Powered by Google App Engine
This is Rietveld 408576698